@@ -14,7 +14,7 @@ use Types::Standard ();
 
 use base 'Exporter::Tiny';
 
-our $VERSION = '0.23'; # VERSION
+our $VERSION = '0.24'; # VERSION
 
 our $EXTS = {
     ARRAY     => 'Bubblegum::Object::Array',
@@ -145,6 +145,7 @@ sub _handle_attr {
                     $props{isa} = $type;
                 }
                 if ($builder or $builder = $target->can("_build_${name}")) {
+                    $props{lazy}    = 1;
                     $props{builder} = "_build_${name}";
                     unless ($target->can("_build_${name}")) {
                         *{"${target}::$props{builder}"} = $builder;
@@ -199,7 +200,7 @@ Bubblegum::Constraints - Type and Constraints Library for Bubblegum
 
 =head1 VERSION
 
-version 0.23
+version 0.24
 
 =head1 SYNOPSIS
 
@@ -271,6 +272,7 @@ is the equivalent of:
 
     has 'attr1' => (
         is      => 'ro',
+        lazy    => 1,
         builder => '_build_attr1',
     );
 
@@ -281,6 +283,7 @@ is the equivalent of:
     has 'attr2' => (
         is      => 'ro',
         isa     => typeof_object,
+        lazy    => 1,
         builder => '_build_attr2',
     );
 
@@ -303,6 +306,7 @@ is the equivalent of:
 
     has 'attr1' => (
         is      => 'ro',
+        lazy    => 1,
         builder => '_build_attr1',
     );
 
